@@ -16,7 +16,7 @@ from django.utils.formats import date_format
 from django.utils.html import format_html
 from django.utils.safestring import mark_safe
 from django.contrib.admin import widgets
-from django.utils.text import format_lazy
+from django.utils.text import format_lazy, capfirst
 from django.utils.timezone import now
 from jacc.format import align_lines
 from jacc.forms import ReverseChargeForm
@@ -29,6 +29,9 @@ from jacc.models import (
     AccountEntrySourceFile,
     INVOICE_STATE,
     AccountEntryNote,
+    INVOICE_NOT_DUE_YET,
+    INVOICE_DUE,
+    INVOICE_LATE,
 )
 from django.conf import settings
 from django.contrib import admin
@@ -245,7 +248,7 @@ class AccountEntryAdmin(ModelAdminBase):
         summarize_account_entries,
         add_reverse_charge,
     ]
-    list_display: Sequence[str] = [
+    list_display = [
         "id",
         "timestamp",
         "account_link",
@@ -253,7 +256,7 @@ class AccountEntryAdmin(ModelAdminBase):
         "amount",
         "parent",
     ]
-    raw_id_fields: Sequence[str] = [
+    raw_id_fields = [
         "account",
         "source_file",
         "type",
@@ -263,15 +266,15 @@ class AccountEntryAdmin(ModelAdminBase):
         "settled_item",
         "parent",
     ]
-    ordering: Sequence[str] = [
+    ordering = [
         "-id",
     ]
-    search_fields: Sequence[str] = [
+    search_fields = [
         "=id",
         "=amount",
         "description",
     ]
-    fields: Sequence[str] = [
+    fields = [
         "id",
         "account",
         "timestamp",
@@ -287,7 +290,7 @@ class AccountEntryAdmin(ModelAdminBase):
         "parent",
         "archived",
     ]
-    readonly_fields: Sequence[str] = [
+    readonly_fields = [
         "id",
         "created",
         "last_modified",
@@ -297,7 +300,7 @@ class AccountEntryAdmin(ModelAdminBase):
         "settled_item_link",
         "archived",
     ]
-    list_filter: Sequence[Any] = [
+    list_filter = [
         SettlementAccountEntryFilter,
         EntryTypeAccountEntryFilter,
         AccountTypeAccountEntryFilter,
@@ -437,7 +440,7 @@ class AccountEntryAdmin(ModelAdminBase):
 
 
 class AccountAdmin(ModelAdminBase):
-    list_display: Sequence[str] = [
+    list_display = [
         "id",
         "type",
         "name",
@@ -449,18 +452,18 @@ class AccountAdmin(ModelAdminBase):
     search_fields = [
         "name",
     ]
-    readonly_fields: Sequence[str] = [
+    readonly_fields = [
         "id",
         "balance",
         "is_asset",
     ]
-    raw_id_fields: Sequence[str] = [
+    raw_id_fields = [
         "type",
     ]
-    ordering: Sequence[str] = [
+    ordering = [
         "-id",
     ]
-    list_filter: Sequence[Any] = [
+    list_filter = [
         "type",
         "type__is_asset",
     ]
@@ -719,6 +722,31 @@ def summarize_invoice_statistics(modeladmin, request: HttpRequest, qs: QuerySet)
     messages.add_message(request, INFO, format_html("<br>".join(lines)), extra_tags="safe")
 
 
+class InvoiceStateFilter(SimpleListFilter):
+    title = _("state")
+    parameter_name = "invoice-state"
+
+    def lookups(self, request, model_admin):
+        return [
+            ("O", capfirst(_("outstanding.invoice"))),
+            (INVOICE_NOT_DUE_YET, mark_safe("&nbsp;" * 4 + _("Not due yet"))),
+            (INVOICE_DUE, mark_safe("&nbsp;" * 4 + _("Due"))),
+            (INVOICE_LATE, mark_safe("&nbsp;" * 4 + _("Late"))),
+            ("C", capfirst(_("closed.invoice"))),
+        ]
+
+    def queryset(self, request, queryset):
+        val = self.value()
+        if val:
+            if val == "O":
+                queryset = queryset.filter(close_date=None)
+            elif val == "C":
+                queryset = queryset.exclude(close_date=None)
+            else:
+                queryset = queryset.filter(state=val)
+        return queryset
+
+
 class InvoiceAdmin(ModelAdminBase):
     """
     Invoice admin. Override following in derived classes:
@@ -738,7 +766,7 @@ class InvoiceAdmin(ModelAdminBase):
         InvoiceItemInline,  # TODO: override in app
         InvoiceSettlementInline,  # TODO: override in app
     ]
-    list_display: Sequence[str] = [
+    list_display = [
         "number",
         "created_brief",
         "sent_brief",
@@ -749,7 +777,7 @@ class InvoiceAdmin(ModelAdminBase):
         "paid_amount",
         "unpaid_amount",
     ]
-    fields: Sequence[str] = [
+    fields = [
         "type",
         "number",
         "due_date",
@@ -766,7 +794,7 @@ class InvoiceAdmin(ModelAdminBase):
         "last_modified",
         "sent",
     ]
-    readonly_fields: Sequence[str] = [
+    readonly_fields = [
         "created",
         "last_modified",
         "sent",
@@ -783,14 +811,14 @@ class InvoiceAdmin(ModelAdminBase):
         "overpaid_amount",
         "late_days",
     ]
-    raw_id_fields: Sequence[str] = []
-    search_fields: Sequence[str] = [
+    raw_id_fields = []
+    search_fields = [
         "=amount",
         "=filename",
         "=number",
     ]
-    list_filter: Sequence[Any] = [
-        "state",
+    list_filter = [
+        InvoiceStateFilter,
         InvoiceLateDaysFilter,
     ]
     allow_add = True
@@ -911,11 +939,11 @@ class EntryTypeAdmin(ModelAdminBase):
         "is_payment",
         "payback_priority",
     ]
-    list_filter: Sequence[Any] = (
+    list_filter = (
         "is_settlement",
         "is_payment",
     )
-    search_fields: Sequence[str] = (
+    search_fields = (
         "=code",
         "name",
     )
@@ -923,8 +951,8 @@ class EntryTypeAdmin(ModelAdminBase):
         toggle_settlement,
         toggle_payment,
     ]
-    exclude: Sequence[str] = ()
-    ordering: Sequence[str] = [
+    exclude = ()
+    ordering = [
         "name",
     ]
     allow_add = True
@@ -932,25 +960,25 @@ class EntryTypeAdmin(ModelAdminBase):
 
 
 class AccountEntrySourceFileAdmin(ModelAdminBase):
-    list_display: Sequence[str] = [
+    list_display = [
         "id",
         "created",
         "entries_link",
     ]
     date_hierarchy = "created"
-    ordering: Sequence[str] = [
+    ordering = [
         "-id",
     ]
-    fields: Sequence[str] = [
+    fields = [
         "id",
         "name",
         "created",
         "last_modified",
     ]
-    search_fields: Sequence[str] = [
+    search_fields = [
         "=name",
     ]
-    readonly_fields: Sequence[str] = [
+    readonly_fields = [
         "id",
         "created",
         "name",
